@@ -1,4 +1,4 @@
-from Functionals import mapFunc
+from pipefun.Functionals import mapFunc
 
 out = lambda *xs: None
 
